import { EventEmitter, ElementRef, ComponentRef, Renderer2, ComponentFactoryResolver, Injector, ApplicationRef, AfterViewInit, OnDestroy, OnChanges } from '@angular/core';
import { BehaviorSubject } from 'rxjs/BehaviorSubject';
import { Observable } from 'rxjs/Observable';
import 'rxjs/add/operator/filter';
import { NzbPopupStatus } from './nzb-popup-status.enum';
import { NzbDynamicContentComponent } from '../dynamic-content/nzb-dynamic-content.component';
import { NzbPopoverOptions } from './nzb-popover-options.class';
import { NzbTooltipOptions } from './nzb-tooltip-options.class';
export declare abstract class NzbPopup implements AfterViewInit, OnDestroy, OnChanges {
    protected bootstrapComponentName: 'popover' | 'tooltip';
    protected cfr: ComponentFactoryResolver;
    protected injector: Injector;
    protected appRef: ApplicationRef;
    protected renderer: Renderer2;
    protected element: ElementRef;
    protected injectedOptions: any;
    protected titleComponentRef: ComponentRef<NzbDynamicContentComponent>;
    protected contentComponentRef: ComponentRef<NzbDynamicContentComponent>;
    private factory;
    protected options: NzbPopoverOptions | NzbTooltipOptions;
    private showTriggerUnlisteners;
    private hideTriggerUnlisteners;
    /**
     * Passes on the native Bootstrap `show.bs.*` event
     * @type {EventEmitter<any>}
     */
    onShow: EventEmitter<any>;
    /**
     * Passes on the native Bootstrap `shown.bs.*` event
     * @type {EventEmitter<any>}
     */
    onShown: EventEmitter<any>;
    /**
     * Passes on the native Bootstrap `hide.bs.*` event
     * @type {EventEmitter<any>}
     */
    onHide: EventEmitter<any>;
    /**
     * Passes on the native Bootstrap `hidden.bs.*` event
     * @type {EventEmitter<any>}
     */
    onHidden: EventEmitter<any>;
    /**
     * The status.
     * @protected
     * @type {BehaviorSubject<NzbModalStatus>}
     */
    protected statusSubject: BehaviorSubject<NzbPopupStatus>;
    readonly status: Observable<NzbPopupStatus>;
    constructor(bootstrapComponentName: 'popover' | 'tooltip', cfr: ComponentFactoryResolver, injector: Injector, appRef: ApplicationRef, renderer: Renderer2, element: ElementRef, injectedOptions: any);
    protected abstract getContext(): any;
    protected abstract getInstanceOptions(): any;
    protected updateOptions(): void;
    protected getBootstrapEvents(): string[];
    protected initializeBootstrapEvents(target: ElementRef): void;
    protected destroyBootstrapEvents(target: ElementRef): void;
    protected initializeShowTriggers(): string | null;
    protected setHideTriggers(): void;
    protected updateComponents(): void;
    protected createDynamicContentComponent(): ComponentRef<NzbDynamicContentComponent>;
    protected initTitleComponent(): void;
    protected initContentComponent(): void;
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    ngOnChanges(): void;
    show(): void;
    hide(): void;
    /**
     * A promise that resolves once when the popup is opened, i.e. after all the Bootstrap animations complete.
     * @return {Promise<void>}
     */
    shown(): Promise<void>;
    /**
     * A promise that resolves once when the popup is opened, i.e. after all the Bootstrap animations complete.
     * @return {Promise<void>}
     */
    hidden(): Promise<void>;
}
